==> genometools-1.2.2.tar.gz: genometools-1.2.2/gtpython/gt/core/array.py <==
#
# Copyright (c) 2008 Sascha Steinbiss <steinbiss@zbh.uni-hamburg.de>
# Copyright (c) 2008 Center for Bioinformatics, University of Hamburg
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

from gt.dlload import gtlib

class Array:
  def __init__(self, arr):
    self.array = arr
    self._as_parameter_ = self.array

  def __del__(self):
    gtlib.gt_array_delete(self.array)

  def from_param(cls, obj):
    if not isinstance(obj, Array):
      raise TypeError, "argument must be an Array"
    return obj._as_parameter_
  from_param = classmethod(from_param)

  def get(self, i):
    return gtlib.gt_array_get(self.array, i).contents

  def size(self):
    return gtlib.gt_array_size(self.array)

  def register(cls, gtlib):
    from ctypes import c_void_p, c_ulong, POINTER
    gtlib.gt_str_new_cstr.argtypes = [c_void_p, c_ulong]
    gtlib.gt_array_get.restype = POINTER(c_void_p)
    gtlib.gt_array_size.restype = c_ulong
  register = classmethod(register)

==> genometools-1.3.0.tar.gz: genometools-1.3.0/gtpython/gt/core/array.py <==
#
# Copyright (c) 2008 Sascha Steinbiss <steinbiss@zbh.uni-hamburg.de>
# Copyright (c) 2008 Center for Bioinformatics, University of Hamburg
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

from gt.dlload import gtlib

class Array:
  def create(size, own = True):
    return Array(gtlib.gt_array_new(size), own)
  create = staticmethod(create)

  def __init__(self, arr, own = False):
    self.array = arr
    self._as_parameter_ = self.array
    self.own = own

  def __del__(self):
    if self.own:
      try:
        gtlib.gt_array_delete(self.array)
      except AttributeError:
        pass

  def from_param(cls, obj):
    if not isinstance(obj, Array):
      raise TypeError, "argument must be an Array"
    return obj._as_parameter_
  from_param = classmethod(from_param)

  def get(self, i):
    return gtlib.gt_array_get(self.array, i).contents

  def size(self):
    return gtlib.gt_array_size(self.array)

  def add(self, val):
    gtlib.gt_array_add_ptr(self.array, val._as_parameter_)

  def register(cls, gtlib):
    from ctypes import c_void_p, c_uint, c_ulong, POINTER
    gtlib.gt_array_new.restype = c_void_p
    gtlib.gt_array_new.argtypes = [c_uint]
    gtlib.gt_array_ref.restype = c_void_p
    gtlib.gt_array_ref.argtypes = [c_void_p]
    gtlib.gt_array_get.restype = POINTER(c_void_p)
    gtlib.gt_array_get.argtypes = [c_ulong]
    gtlib.gt_array_size.restype = c_ulong
    gtlib.gt_array_add_ptr.argtypes = [c_void_p, c_void_p]
  register = classmethod(register)
